@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTNETWORK_PYTHON_H
@@ -76,6 +40,7 @@
 #include <QtNetwork/qtcpserver.h>
 #include <QtNetwork/qssl.h>
 #include <QtNetwork/qpassworddigestor.h>
+#include <QtNetwork/qsslserver.h>
 #include <QtNetwork/qabstractsocket.h>
 #include <QtNetwork/qhostaddress.h>
 #include <QtNetwork/qhostinfo.h>
@@ -222,16 +187,17 @@ enum : int {
     SBK_QSSLERROR_IDX                                        = 109,
     SBK_QSSLKEY_IDX                                          = 111,
     SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 112,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 115,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 114,
-    SBK_QSSLSOCKET_IDX                                       = 113,
-    SBK_QTCPSERVER_IDX                                       = 116,
-    SBK_QTCPSOCKET_IDX                                       = 117,
-    SBK_QUDPSOCKET_IDX                                       = 118,
+    SBK_QSSLSERVER_IDX                                       = 113,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 116,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 115,
+    SBK_QSSLSOCKET_IDX                                       = 114,
+    SBK_QTCPSERVER_IDX                                       = 117,
+    SBK_QTCPSOCKET_IDX                                       = 118,
+    SBK_QUDPSOCKET_IDX                                       = 119,
     SBK_QDTLSERROR_IDX                                       = 21,
     SBK_QOCSPCERTIFICATESTATUS_IDX                           = 84,
     SBK_QOCSPREVOCATIONREASON_IDX                            = 86,
-    SBK_QtNetwork_IDX_COUNT                                  = 119
+    SBK_QtNetwork_IDX_COUNT                                  = 120
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtNetworkTypes;
@@ -398,6 +364,7 @@ template<> inline PyTypeObject *SbkType< ::QSslError::SslError >() { return SbkP
 template<> inline PyTypeObject *SbkType< ::QSslError >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLERROR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslKey >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLKEY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslPreSharedKeyAuthenticator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSslServer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLSERVER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslSocket::SslMode >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLSOCKET_SSLMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslSocket::PeerVerifyMode >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLSOCKET_PEERVERIFYMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLSOCKET_IDX]); }
